<?php
/*
Plugin Name: Moderator
Plugin URI: http://www.danieldura.com/moderator/
Description: Moderate comments from your WordPress blog on your desktop.
Author: Daniel Dura
Version: 0.1
Author URI: http://www.danieldura.com
Copyright: 2008 Daniel Dura
*/

function moderator_escape(&$array) {
	global $wpdb;

	if(!is_array($array)) {
		return($wpdb->escape($array));
	}
	else {
		foreach ( (array) $array as $k => $v ) {
			if (is_array($v)) {
				$this->escape($array[$k]);
			} else if (is_object($v)) {
				//skip
			} else {
				$array[$k] = $wpdb->escape($v);
			}
		}
	}
}

function moderator_getUnmoderatedComments( $args ) {
	moderator_escape( $args );
	
	$username = $args[0];
	$password = $args[1];
	
	set_current_user( 0, $username );
	if( !user_pass_ok( $username, $password ) )
		return new IXR_Error(403, 'Bad login/pass combination.');
	if( !current_user_can( 'moderate_comments' ) )
		return new IXR_Error( 401, 'Sorry, you are unable to moderate comments.');
	
	global $wpdb;
	return $wpdb->get_results($wpdb->prepare("SELECT * FROM $wpdb->comments WHERE comment_approved = '0' ORDER BY comment_date"));
}

function moderator_approveComment( $args ) {
	moderator_escape( $args );
	
	$username = $args[0];
	$password = $args[1];
	$commentId = $args[2];
	
	set_current_user( 0, $username );
	if( !user_pass_ok( $username, $password) )
		return new IXR_Error(403, 'Bad login/pass combination.');
	if( !current_user_can( 'moderate_comments' ) )
		return new IXR_Error( 401, 'Sorry, you are unable to moderate comments.');
		
	if( !wp_set_comment_status( $commentId, 'approve' ) )
		return new IXR_Error(401, __( 'Sorry, unable to approve comment.' ) );
}

function moderator_spamComment( $args ) {
	moderator_escape( $args );
	
	$username = $args[0];
	$password = $args[1];
	$commentId = $args[2];
	
	set_current_user( 0, $username );
	if( !user_pass_ok( $username, $password) )
		return new IXR_Error(403, 'Bad login/pass combination.');
	if( !current_user_can( 'moderate_comments' ) )
		return new IXR_Error( 401, 'Sorry, you are unable to moderate comments.');
		
	if( !wp_set_comment_status( $commentId, 'spam' ) )
		return new IXR_Error(401, __( 'Sorry, unable to mark as spam.' ) );	
}

function moderator_deleteComment( $args ) {
	moderator_escape( $args );
	
	$username = $args[0];
	$password = $args[1];
	$commentId = $args[2];
	
	set_current_user( 0, $username );
	if( !user_pass_ok( $username, $password) )
		return new IXR_Error(403, 'Bad login/pass combination.');		
	if( !current_user_can( 'moderate_comments' ) )
		return new IXR_Error( 401, 'Sorry, you are unable to moderate comments.');
		
	if( !wp_set_comment_status( $commentId, 'delete' ) )
		return new IXR_Error(401, __( 'Sorry, unable to mark as spam.' ) );	
}

function moderator_getUserInfo( $args ) {
	moderator_escape($args);

	$username = $args[0];
	$password  = $args[1];

	set_current_user( 0, $username );
	if( !user_pass_ok( $username, $password) )
		return new IXR_Error(403, 'Bad login/pass combination.');
	if( !current_user_can( 'edit_posts' ) )
		return new IXR_Error( 401, __( 'Sorry, you do not have access to user data on this blog.' ) );

	$user_data = get_userdatabylogin($username);

	$struct = array(
		'nickname'  => $user_data->nickname,
		'userid'    => $user_data->ID,
		'url'       => $user_data->user_url,
		'lastname'  => $user_data->last_name,
		'firstname' => $user_data->first_name,
		'moderator_version' => '0.1'
	);

	return $struct;
}

function attach_new_xmlrpc($methods) {
	$methods['moderator.getUserInfo'] = 'moderator_getUserInfo';
	$methods['moderator.spamComment'] = 'moderator_spamComment';
    $methods['moderator.getUnmoderatedComments'] = 'moderator_getUnmoderatedComments';
    $methods['moderator.approveComment'] = 'moderator_approveComment';
	$methods['moderator.deleteComment'] = 'moderator_deleteComment';
    return $methods;
}

function wpnotify_add_admin_pages() {
	add_options_page('Moderator Options Page', 'Moderator', 8, __FILE__, 'wpnotify_moderator_admin');
}

function wpnotify_moderator_admin() {
	?>
	<div class="wrap">
		<h2>Install the Moderator Desktop Client</h2>
		<p>Now that you have installed the Moderator Plugin for Wordpress, you are ready to install the Moderator desktop client! Click on the badge below
		to install. This application makes use of the <a href="http://www.adobe.com/go/air" target="_blank">Adobe AIR</a> runtime. If you do not already have Adobe AIR installed, the badge will install it for you.</p>
		<p>While Moderator is powered by Adobe AIR, it is not a product of or supported by Adobe Systems, Inc. Moderator is created and supported by <a href="http://www.danieldura.com" target="_blank">Daniel Dura</a> in his freetime. For bug reports and
		features requests, please email <a href="mailto:wpmoderator@gmail.com">wpmoderator@gmail.com</a>. Or if you would like to contact Daniel directly, send a mail to daniel.dura@gmail.com.</p>
		<p><strong>Please note, this is alpha software, and as such will have bugs. Install at your own risk.</strong></p>
		<div id="flashcontent" style="width:215px; height:180px;">
			<strong>Please upgrade your Flash Player so that you can install the Moderator application. Moderator was created using Adobe AIR.</strong>
		</div>
		<p>If you do not see an install badge above with an 'Install Now' button, you may have to manually install Adobe AIR and the Moderator application. If that is the
		case, follow these instructions:</p>
		<ol>
			<li>Go to <a href="http://www.adobe.com/go/air">http://www.adobe.com/go/air</a> and download the Adobe AIR runtime installer for your operating system. Follow the install instructions.</li>
			<li>Once the Adobe AIR runtime is installed, download the <a href="http://www.danieldura.com/moderatorfiles/moderator_current.air">Moderator AIR install file here.</a></li>
			<li>Initiate the Moderator install by double clicking on the file and following the instructions.</li>
		</ol>
	</div>
	<script type="text/javascript" src="<?php echo get_settings('siteurl') . '/wp-content/plugins/moderator/swfobject.js' ?>"></script>
	<script type="text/javascript">
		// <![CDATA[
		
		// version 9.0.115 or greater is required for launching AIR apps.
		var so = new SWFObject("<?php echo get_settings('siteurl') . '/wp-content/plugins/moderator/AIRInstallBadge.swf' ?>", "Badge", "215", "180", "9.0.115", "#FFFFFF");
		so.useExpressInstall('<?php echo get_settings('siteurl') . '/wp-content/plugins/moderator/expressinstall.swf' ?>');
		
		// these parameters are required for badge install:
		so.addVariable("airversion", "1.0"); // version of AIR runtime required
		so.addVariable("appname", "Moderator Desktop Client"); // application name to display to the user
		so.addVariable("appurl", "http://www.danieldura.com/moderatorfiles/moderator_current.air"); // absolute URL (beginning with http or https) of the application ".air" file
		
		// these parameters are required to support launching apps from the badge (but optional for install):
		so.addVariable("appid", "com.danieldura.moderator.main"); // the qualified application ID (ex. com.gskinner.air.MyApplication)
		so.addVariable("pubid", ""); // publisher id
		
		// this parameter is required in addition to the above to support upgrading from the badge:
		so.addVariable("appversion", "0.1"); // AIR application version
		
		// these parameters are optional:
		
		so.addVariable("imageurl", "<?php echo get_settings('siteurl') . '/wp-content/plugins/moderator/screenshot.jpg' ?>"); // URL for an image (JPG, PNG, GIF) or SWF to display in the badge (205px wide, 170px high)
		/*so.addVariable("appinstallarg", "installed from web"); // passed to the application when it is installed from the badge
		so.addVariable("applauncharg", "launched from web"); // passed to the application when it is launched from the badge
		so.addVariable("helpurl", "help.html"); // optional url to a page containing additional help, displayed in the badge's help screen
		so.addVariable("hidehelp", "false"); // hides the help icon if "true"
		so.addVariable("skiptransition", "false"); // skips the initial transition if "true"
		so.addVariable("titlecolor", "#00AAFF"); // changes the color of titles
		so.addVariable("buttonlabelcolor", "#00AAFF"); // changes the color of the button label
		so.addVariable("appnamecolor", "#00AAFF"); // changes the color of the application name if the image is not specified or loaded
		*/
		
		// these parameters allow you to override the default text in the badge:
		// supported strings: str_error, str_err_params, str_err_airunavailable, str_err_airswf, str_loading, str_install, str_launch, str_upgrade, str_close, str_launching, str_launchingtext, str_installing, str_installingtext, str_tryagain, str_beta3, str_beta3text, str_help, str_helptext
		//so.addVariable("str_err_airswf", "<u>Running locally?</u><br/><br/>The AIR proxy swf won't load properly when this demo is run from the local file system."); // overrides the error text when the AIR proxy swf fails to load
		
		so.write("flashcontent");
		
		// ]]>
	</script>		
	<?php
}

add_action('admin_menu', 'wpnotify_add_admin_pages');
add_action('xmlrpc_methods', 'attach_new_xmlrpc');
?>